<p align="center">
  <img src="https://img.shields.io/pypi/v/cpf_utils.svg" alt="PyPI version">
  <img src="https://img.shields.io/github/license/seuusuario/cpf_utils.svg" alt="License">
  <img src="https://img.shields.io/github/actions/workflow/status/seuusuario/cpf_utils/tests.yml" alt="Build Status">
  <img src="https://img.shields.io/pypi/dm/cpf_utils.svg" alt="Downloads">
</p>
